
#ifndef _DATAFPX_H_
#define _DATAFPX_H_

#pragma pack (4)

/***************************************************************************/
/* GENERAL DEFINITIONS:                                                    */
/***************************************************************************/

#define INST_NAME_LEN         40

#define MAX_BOARD             4
#define LG_BOARD_NAME         9

#define MAX_FPX3_INST         (64 * MAX_BOARD)
#define MAX_FPX2_INST         (3 * MAX_BOARD)
#define MAX_FPX1_INST         (2 * MAX_BOARD)

#define PERF_DETAIL_NONE      0x300
#define MAX_INSTANCES         (MAX_FPX3_INST + MAX_FPX2_INST + MAX_FPX1_INST)
#define LG_NAME               16

/***************************************************************************/
/* OBJECT DEFINITIONS:                                                     */
/***************************************************************************/

#define FPX_NUM_PERF_OBJECT_TYPES 3

//----------------------------------------------------------------------------
//
//  Nbf Resource object type counter definitions.
//
//  These are used in the counter definitions to describe the relative
//  position of each counter in the returned data.
//
//----------------------------------------------------------------------------

// OBJET 3
#define D_FPXOBJ3             0
#define D_VOLEFPX3            2
#define D_VOLRFPX3            4
#define D_MESEFPX3            6
#define D_MESRFPX3            8
#define D_CVONFPX3            10
#define D_CALLFPX3            12
#define D_LIBLFPX3            14
#define D_LIBRFPX3            16
#define D_CAUSEFPX3           18
#define D_DIAGFPX3            20
#define D_THPBYTE3            22
#define D_CVINFPX3            24
#define D_CVOUTFPX3           26

// OBJET 2
#define D_FPXOBJ2             28
#define D_VOLEFPX2            30
#define D_VOLRFPX2            32
#define D_MESEFPX2            34
#define D_MESRFPX2            36

// OBJET 1
#define D_FPXOBJ1             38
#define D_VOLEFPX1            40
#define D_VOLRFPX1            42
#define D_V28FPX1             44

// OBJET 3
#define NUM_FPX3_OFFSET       sizeof(DWORD)

#define NUM_VOLEFPX3_OFFSET   sizeof(DWORD)
#define NUM_VOLRFPX3_OFFSET   NUM_VOLEFPX3_OFFSET  + sizeof(DWORD)
#define NUM_MESEFPX3_OFFSET   NUM_VOLRFPX3_OFFSET  + sizeof(DWORD)
#define NUM_MESRFPX3_OFFSET   NUM_MESEFPX3_OFFSET  + sizeof(DWORD)
#define NUM_CVONFPX3_OFFSET   NUM_MESRFPX3_OFFSET  + sizeof(DWORD)
#define NUM_CALLFPX3_OFFSET   NUM_CVONFPX3_OFFSET  + sizeof(DWORD)
#define NUM_LIBLFPX3_OFFSET   NUM_CALLFPX3_OFFSET  + sizeof(DWORD)
#define NUM_LIBRFPX3_OFFSET   NUM_LIBLFPX3_OFFSET  + sizeof(DWORD)
#define NUM_CAUSEFPX3_OFFSET  NUM_LIBRFPX3_OFFSET  + sizeof(DWORD)
#define NUM_DIAGFPX3_OFFSET   NUM_CAUSEFPX3_OFFSET + sizeof(DWORD)
#define NUM_THPBYTE3_OFFSET   NUM_DIAGFPX3_OFFSET  + sizeof(DWORD)
#define NUM_CVINFPX3_OFFSET   NUM_THPBYTE3_OFFSET  + sizeof(DWORD)
#define NUM_CVOUTFPX3_OFFSET  NUM_CVINFPX3_OFFSET  + sizeof(DWORD)

#define SIZE_OF_FPX3_PERFORMANCE_DATA NUM_CVOUTFPX3_OFFSET \
                    + sizeof(DWORD)

// OBJET 2
#define NUM_FPX2_OFFSET       sizeof(DWORD)

#define NUM_VOLEFPX2_OFFSET   sizeof(DWORD)
#define NUM_VOLRFPX2_OFFSET   NUM_VOLEFPX2_OFFSET   + sizeof(DWORD)
#define NUM_MESEFPX2_OFFSET   NUM_VOLRFPX2_OFFSET   + sizeof(DWORD)
#define NUM_MESRFPX2_OFFSET   NUM_MESEFPX2_OFFSET   + sizeof(DWORD)

#define SIZE_OF_FPX2_PERFORMANCE_DATA NUM_MESRFPX2_OFFSET \
                    + sizeof(DWORD)

// OBJET 1
#define NUM_FPX1_OFFSET       sizeof(DWORD)

#define NUM_VOLEFPX1_OFFSET   sizeof(DWORD)
#define NUM_VOLRFPX1_OFFSET   NUM_VOLEFPX1_OFFSET   + sizeof(DWORD)
#define NUM_V28FPX1_OFFSET   NUM_VOLRFPX1_OFFSET   + sizeof(DWORD)

#define SIZE_OF_FPX1_PERFORMANCE_DATA NUM_V28FPX1_OFFSET \
                    + sizeof(DWORD)


/***************************************************************************/
/* STRUCTURE DEFINITIONS:                                                  */
/***************************************************************************/

//----------------------------------------------------------------------------
//
//  This is the counter structure presently returned by Nbf for
//  each Resource.  Each Resource is an Instance, named by its number.
//
//----------------------------------------------------------------------------

typedef struct _FPX_DATA_DEFINITION3 {

    PERF_OBJECT_TYPE          OBJECT;
    PERF_COUNTER_DEFINITION  VOLEFPX3 ;
    PERF_COUNTER_DEFINITION  VOLRFPX3 ;
    PERF_COUNTER_DEFINITION  MESEFPX3 ;
    PERF_COUNTER_DEFINITION  MESRFPX3 ;
    PERF_COUNTER_DEFINITION  CVONFPX3 ;
    PERF_COUNTER_DEFINITION  CALLFPX3 ;
    PERF_COUNTER_DEFINITION  LIBLFPX3 ;
    PERF_COUNTER_DEFINITION  LIBRFPX3 ;
    PERF_COUNTER_DEFINITION  CAUSEFPX3 ;
    PERF_COUNTER_DEFINITION  DIAGFPX3 ;
    PERF_COUNTER_DEFINITION  THPBYTE3 ;
    PERF_COUNTER_DEFINITION  CVINFPX3 ;
    PERF_COUNTER_DEFINITION  CVOUTFPX3 ;

} FPX_DATA_DEFINITION3;

typedef struct _FPX_DATA_DEFINITION2 {

    PERF_OBJECT_TYPE          OBJECT;
    PERF_COUNTER_DEFINITION  VOLEFPX2 ;
    PERF_COUNTER_DEFINITION  VOLRFPX2 ;
    PERF_COUNTER_DEFINITION  MESEFPX2 ;
    PERF_COUNTER_DEFINITION  MESRFPX2 ;

} FPX_DATA_DEFINITION2;

typedef struct _FPX_DATA_DEFINITION1 {

    PERF_OBJECT_TYPE          OBJECT;
    PERF_COUNTER_DEFINITION  VOLEFPX1 ;
    PERF_COUNTER_DEFINITION  VOLRFPX1 ;
    PERF_COUNTER_DEFINITION  V28FPX1 ;

} FPX_DATA_DEFINITION1;


typedef struct _FPX_INSTANCE {

    TCHAR      NAME[INST_NAME_LEN];
    WORD       LGN;

} FPX_INSTANCE;

typedef struct _FPX_BOARD  {

     TCHAR     Name[LG_BOARD_NAME];
     WORD      Num;
     WORD      AChannel;
     WORD      BChannel;

} FPX_BOARD;

#pragma pack ()

#endif //_DATAFPX_H_

/***************************************************************************/
